@@ -1,6 +1,6 @@
 cum2mom <-
-function(n=0) {
-  v<-MFB(n,1);                                  # Recall MFB Function
+function(n=1) {
+  v<-MFB(n,1);                                  # Call the MFB Function
   v<-MFB2Set( v );                              # Expression to vector 
   for (j in 1:length(v)) {
       # ----- read -----------[ fix block ]-----#---------------#
@@ -10,13 +10,13 @@ function(n=0) {
         k <-       strtoi(v[[j]][5]);           # power
       # ----- change ---------------------------#---------------#
       if (x=="f") {
-          i<-strtoi(i);       #[fix]            # as integer
+          i<-strtoi(i);                         # as integer
           c<-paste0(c,"*(-1)^(",i-1,")*factorial(",i-1,")" );
           x<-""; 
           i<-""; 
       } 
       else if (x=="g") {
-          x<-"u";
+          x<-"m";
       }
       # ----- write ---------[ fix block ]------#---------------#
         v[[j]][2] <- c;
